==> theme-bootstrap-1.0.95.tgz: package/src/components/services-menu/services-menu.jsx <==
import React, { Component, Fragment } from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage } from 'react-intl';
import classnames from 'classnames';
import Popover from 'reactstrap/lib/Popover';
import PopoverBody from 'reactstrap/lib/PopoverBody';

import { IconServices } from '../icons/icon-services/icon-services';
import GA from '../../helpers/ga';
import './services-menu.scss';
import { ENTER_KEY_CODE } from '../../constants';

const SERVICES_MENU_ID = 'SERVICES_MENU_ID';

export class ServicesMenu extends Component {
  static propTypes = {
    serviceItems: PropTypes.arrayOf(PropTypes.shape({
      link: PropTypes.string.isRequired,
      message: PropTypes.string.isRequired,
      service: PropTypes.string.isRequired,
      icon: PropTypes.node.isRequired,
    })).isRequired,
    hostname: PropTypes.string.isRequired,
    className: PropTypes.string,
  };

  static defaultProps = {
    className: '',
  };

  state = {
    menuOpen: false,
  };

  toggleMenu = () => {
    if (!this.state.menuOpen) {
      GA.event({ category: 'Services', action: 'Services' });
    }
    this.setState(previousState => ({
      menuOpen: !previousState.menuOpen,
    }));
  };

  fireAction = (e) => {
    const action = e.currentTarget.dataset.service;
    GA.event({ category: 'Services', action });
  };

  serviceKeyPress = (e) => {
    const { which, keyCode } = e;
    const charCode = which || keyCode;
    if (charCode === ENTER_KEY_CODE) {
      this.fireAction(e);
    }
  };

  renderServiceItems = () => {
    const { serviceItems, hostname } = this.props;
    const hostnameRegexp = new RegExp(`^((https?:)?//)?${hostname}`);

    return serviceItems.map(({
      link, message, icon, service,
    }) => {
      const hrefProps = link.match(hostnameRegexp)
        ? {
          href: '',
        }
        : {
          href: link,
          target: '_blank',
        };
      return (
        <a
          role="button"
          tabIndex="0"
          className="service-item py-2"
          key={`${link}${message}`}
          data-service={service}
          {...hrefProps}
          onClick={this.fireAction}
          onKeyPress={this.serviceKeyPress}
        >
          {icon}
          <FormattedMessage id={message} />
        </a>
      );
    });
  };

  render() {
    const { menuOpen } = this.state;
    const { className } = this.props;

    return (
      <Fragment>
        <div
          role="button"
          tabIndex="0"
          className={classnames('services-menu-icon d-flex', className)}
          onClick={this.toggleMenu}
          onKeyPress={this.toggleMenu}
          id={SERVICES_MENU_ID}
        >
          <IconServices />
        </div>
        <Popover
          placement="bottom-end"
          hideArrow
          isOpen={menuOpen}
          target={SERVICES_MENU_ID}
          toggle={this.toggleMenu}
          className="popover-services-menu mt-2"
        >
          <PopoverBody>
            <div className="services d-flex flex-wrap">
              {this.renderServiceItems()}
            </div>
          </PopoverBody>
        </Popover>
      </Fragment>
    );
  }
}

==> theme-bootstrap-1.0.114.tgz: package/src/components/services-menu/services-menu.jsx <==
import React, { Component, Fragment } from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage } from 'react-intl';
import classnames from 'classnames';
import Popover from 'reactstrap/lib/Popover';
import PopoverBody from 'reactstrap/lib/PopoverBody';

import { IconServices } from '../icons/icon-services/icon-services';
import GA from '../../helpers/ga';
import './services-menu.scss';
import { CHAR_CODES } from '../../constants';

const SERVICES_MENU_ID = 'SERVICES_MENU_ID';

export class ServicesMenu extends Component {
  static propTypes = {
    serviceItems: PropTypes.arrayOf(PropTypes.shape({
      link: PropTypes.string.isRequired,
      message: PropTypes.string.isRequired,
      service: PropTypes.string.isRequired,
      icon: PropTypes.node.isRequired,
    })).isRequired,
    hostname: PropTypes.string.isRequired,
    className: PropTypes.string,
  };

  static defaultProps = {
    className: '',
  };

  state = {
    menuOpen: false,
  };

  toggleMenu = () => {
    if (!this.state.menuOpen) {
      GA.event({ category: 'Services', action: 'Services' });
    }
    this.setState(previousState => ({
      menuOpen: !previousState.menuOpen,
    }));
  };

  fireAction = (e) => {
    const action = e.currentTarget.dataset.service;
    GA.event({ category: 'Services', action });
  };

  serviceKeyPress = (e) => {
    const { which, keyCode } = e;
    const charCode = which || keyCode;
    if (charCode === CHAR_CODES.ENTER) {
      this.fireAction(e);
    }
  };

  renderServiceItems = () => {
    const { serviceItems, hostname } = this.props;
    const hostnameRegexp = new RegExp(`^((https?:)?//)?${hostname}`);

    return serviceItems.map(({
      link, message, icon, service,
    }) => {
      const hrefProps = link.match(hostnameRegexp)
        ? {
          href: '',
        }
        : {
          href: link,
          target: '_blank',
        };
      return (
        <a
          role="button"
          tabIndex="0"
          className="service-item py-2"
          key={`${link}${message}`}
          data-service={service}
          {...hrefProps}
          onClick={this.fireAction}
          onKeyPress={this.serviceKeyPress}
        >
          {icon}
          <FormattedMessage id={message} />
        </a>
      );
    });
  };

  render() {
    const { menuOpen } = this.state;
    const { className } = this.props;

    return (
      <Fragment>
        <div
          role="button"
          tabIndex="0"
          className={classnames('services-menu-icon d-flex', className)}
          onClick={this.toggleMenu}
          onKeyPress={this.toggleMenu}
          id={SERVICES_MENU_ID}
        >
          <IconServices />
        </div>
        <Popover
          placement="bottom-end"
          hideArrow
          isOpen={menuOpen}
          target={SERVICES_MENU_ID}
          toggle={this.toggleMenu}
          className="popover-services-menu mt-2"
        >
          <PopoverBody>
            <div className="services d-flex flex-wrap">
              {this.renderServiceItems()}
            </div>
          </PopoverBody>
        </Popover>
      </Fragment>
    );
  }
}
